@@ -1,6 +1,6 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
- * $Id: capture.c,v 1.165 2006/04/29 07:58:35 bchiara Exp $
+ * $Id: capture.c,v 1.166 2006/08/13 05:26:50 bchiara Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -464,10 +464,13 @@ start_capture (void)
       return FALSE;
     }
 
-  /* preparing protocol summary and nodes/links catalogs */
-  protocol_summary_open();
-  nodes_catalog_open();
-  links_catalog_open();
+  /* if it's a new capture, we prepare protocol summary and nodes/links catalogs */
+  if (STOP == status)
+    {
+      protocol_summary_open();
+      nodes_catalog_open();
+      links_catalog_open();
+    }
 
   /*
    * See pause_capture for an explanation of why we don't always
