@@ -1,6 +1,6 @@
 /* Etherape
  * Copyright (C) 2000 Juan Toledo
- * $Id: conversations.h,v 1.1 2001/05/10 16:26:24 toledo Exp $
+ * $Id: conversations.h,v 1.4 2006/01/26 07:18:59 bchiara Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,5 +28,9 @@ typedef struct
 }
 conversation_t;
 
-GList *conversations = NULL;	/* Some protocols add an item here to help identify
-				 * further packets of the same protocol */
+void add_conversation (guint32 src_address, guint32 dst_address,
+		       guint16 src_port, guint16 dst_port, const gchar * data);
+gchar *find_conversation (guint32 src_address, guint32 dst_address,
+			  guint16 src_port, guint16 dst_port);
+void delete_conversation_link(guint32 src_address, guint32 dst_address);
+void delete_conversations (void);
