@@ -1,6 +1,6 @@
 /* Etherape
  * Copyright (C) 2000 Juan Toledo
- * $Id: datastructs.h,v 1.3 2005/08/13 18:50:13 bchiara Exp $
+ * $Id: datastructs.h,v 1.6 2006/01/10 07:43:38 bchiara Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,16 +27,13 @@
 /* clears the proto hash */
 void  protohash_clear(void);
 
-/* adds or replaces the protoname item */
-gboolean protohash_set(gchar *protoname, GdkColor protocolor);
-
 /* returns the proto color if exists, NULL otherwise */
-GdkColor * protohash_get(gchar *protoname);
+GdkColor protohash_get(const gchar *protoname);
 
 /* fills the hash from a pref vector */
 gboolean protohash_read_prefvect(gchar **colors, gint n_colors);
 
-/* fills the pref vector from the hash */
-gboolean protohash_write_prefvect(void);
+/* resets the cycle color to start of list */
+void protohash_reset_cycle(void);
 
 #endif
