@@ -33,6 +33,10 @@
 
 
 #include <config.h>
+
+#ifdef USE_DIRECTDNS
+
+
 #include <sys/types.h>
 #include <time.h>
 #include <sys/time.h>
@@ -56,8 +60,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
-#include <ip-cache.h>
-#include <direct_resolve.h>
+#include "ip-cache.h"
+#include "util.h"
+#include "direct_resolve.h"
+
+
 
 #ifdef NO_STRERROR
 extern int sys_nerr;
@@ -223,9 +230,6 @@ static dword res_nxdomain = 0;
 static dword res_nserror = 0;
 static dword res_hostipmismatch = 0;
 static dword res_unknownid = 0;
-static dword res_resend = 0;
-static dword res_timeout = 0;
-static dword resolvecount = 0;
 
 static int resfd = -1;			/* socket file descr. */
 static char tempstring[256];		/* temporary string used as buffer ... */
@@ -787,3 +791,5 @@ direct_lookup (uint32_t ip, int fqdn)
     
   return ipname;
 }
+
+#endif /* USE_DIRECTDNS*/
