@@ -1,6 +1,6 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
- * $Id: main.c,v 1.91 2005/08/17 21:20:21 bchiara Exp $
+ * $Id: main.c,v 1.99 2006/03/25 07:07:44 bchiara Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,10 +23,45 @@
 
 #include <netinet/in.h>
 #include "globals.h"
+#include <signal.h>
+#include <libgnomeui/gnome-client.h>
 #include "ip-cache.h"
 #include "main.h"
+#include "diagram.h"
+#include "preferences.h"
+#include "info_windows.h"
+#include "capture.h"
+#include "datastructs.h"
 
+/***************************************************************************
+ *
+ * local variables
+ *
+ **************************************************************************/
+static gboolean quiet = FALSE;
+static GLogLevelFlags debug_mask;
+static void (*oldhandler) (int);
 
+/***************************************************************************
+ *
+ * internal functions
+ *
+ **************************************************************************/
+static void set_debug_level (void);
+static void session_die (GnomeClient * client, gpointer client_data);
+static gint
+save_session (GnomeClient * client, gint phase, GnomeSaveStyle save_style,
+	      gint is_shutdown, GnomeInteractStyle interact_style,
+	      gint is_fast, gpointer client_data);
+static void
+log_handler (gchar * log_domain,
+	     GLogLevelFlags mask, const gchar * message, gpointer user_data);
+
+/***************************************************************************
+ *
+ * implementation
+ *
+ **************************************************************************/
 int
 main (int argc, char *argv[])
 {
@@ -34,6 +69,7 @@ main (int argc, char *argv[])
   GtkWidget *widget;
   GnomeClient *client;
   gchar *cl_filter = NULL, *cl_interface = NULL, *cl_input_file = NULL;
+  gboolean cl_numeric = FALSE;
   poptContext poptcon;
 
   struct poptOption optionsTable[] = {
@@ -45,7 +81,7 @@ main (int argc, char *argv[])
      N_("set capture filter"), N_("<capture filter>")},
     {"infile", 'r', POPT_ARG_STRING, &cl_input_file, 0,
      N_("set input file"), N_("<file name>")},
-    {"numeric", 'n', POPT_ARG_NONE, &(pref.numeric), 0,
+    {"numeric", 'n', POPT_ARG_NONE, &cl_numeric, 0,
      N_("don't convert addresses to names"), NULL},
     {"diagram-only", 'd', POPT_ARG_NONE, &(pref.diagram_only), 0,
      N_("don't display any node text identification"), NULL},
@@ -61,6 +97,9 @@ main (int argc, char *argv[])
      N_("set the node color"), N_("color")},
     {"text-color", 'T', POPT_ARG_STRING, &(pref.text_color), 0,
      N_("set the text color"), N_("color")},
+    {"zero-delay", 'z', POPT_ARG_NONE, &(pref.zero_delay), 0,
+     N_("zero delay for reading capture files [cli only]"), NULL},
+
 
     POPT_AUTOHELP {NULL, 0, 0, NULL, 0}
   };
@@ -68,6 +107,7 @@ main (int argc, char *argv[])
 
 #ifdef ENABLE_NLS
   bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  bind_textdomain_codeset(PACKAGE, "UTF-8"); /* force UTF-8 conversion */
   textdomain (PACKAGE);
 #endif
 
@@ -87,9 +127,8 @@ main (int argc, char *argv[])
    * Third, whatever given in the command line */
 
   /* Absolute defaults */
-  pref.numeric = 0;
+  pref.name_res = TRUE;
   pref.mode = IP;
-  dns = 1;
   pref.filter = NULL;
   status = STOP;
   pref.refresh_period = 800;	/* ms */
@@ -101,13 +140,13 @@ main (int argc, char *argv[])
   pref.text_color = g_strdup ("yellow");
   pref.node_limit = -1;
 
-
   set_debug_level ();
 
   /* Config file */
   load_config ("/Etherape/");
 
   /* Command line */
+  cl_numeric = !pref.name_res;
   poptcon =
     poptGetContext ("Etherape", argc, (const char **) argv, optionsTable, 0);
   while (poptGetNextOpt (poptcon) > 0);
@@ -132,11 +171,9 @@ main (int argc, char *argv[])
 	g_free (pref.input_file);
       pref.input_file = g_strdup (cl_input_file);
     }
+  pref.name_res = !cl_numeric;
 
 
-  /* dns is used in dns.c as opposite of numeric */
-  dns = !pref.numeric;
-
   /* Find mode of operation */
   if (mode_string)
     {
@@ -169,12 +206,10 @@ main (int argc, char *argv[])
   glade_xml_signal_autoconnect (xml);
 
   app1 = glade_xml_get_widget (xml, "app1");
-  diag_pref = glade_xml_get_widget (xml, "diag_pref");
 
   /* Sets controls to the values of variables and connects signals */
   init_diagram ();
 
-
   /* Session handling */
   client = gnome_master_client ();
   g_signal_connect (G_OBJECT (client), "save_yourself",
@@ -224,186 +259,14 @@ main (int argc, char *argv[])
 
   /* MAIN LOOP */
   gtk_main ();
+
+  protohash_clear();
   return 0;
 }				/* main */
 
 
 
-/* loads configuration from .gnome/Etherape */
-static void
-load_config (char *prefix)
-{
-  gboolean u;
-  gchar *config_file_version;
 
-  gnome_config_push_prefix (prefix);
-
-  config_file_version =
-    gnome_config_get_string_with_default ("General/version=0.5.4", &u);
-  pref.diagram_only =
-    gnome_config_get_bool_with_default ("Diagram/diagram_only=FALSE", &u);
-  pref.group_unk =
-    gnome_config_get_bool_with_default ("Diagram/group_unk=TRUE", &u);
-  pref.stationary
-    = gnome_config_get_bool_with_default ("Diagram/stationary=FALSE", &u);
-  pref.nofade =
-    gnome_config_get_bool_with_default ("Diagram/nofade=FALSE", &u);
-  pref.cycle = gnome_config_get_bool_with_default ("Diagram/cycle=TRUE", &u);
-  pref.antialias =
-    gnome_config_get_bool_with_default ("Diagram/antialias=TRUE", &u);
-  pref.node_timeout_time =
-    gnome_config_get_float_with_default
-    ("Diagram/node_timeout_time=3600000.0", &u);
-  pref.gui_node_timeout_time =
-    gnome_config_get_float_with_default
-    ("Diagram/gui_node_timeout_time=60000.0", &u);
-  if (pref.nofade)
-    pref.link_timeout_time =
-      gnome_config_get_float_with_default
-      ("Diagram/link_timeout_time=5000.0", &u);
-  else
-    pref.link_timeout_time =
-      gnome_config_get_float_with_default
-      ("Diagram/link_timeout_time=20000.0", &u);
-  pref.averaging_time =
-    gnome_config_get_float_with_default ("Diagram/averaging_time=3000.0", &u);
-  pref.node_radius_multiplier =
-    gnome_config_get_float_with_default
-    ("Diagram/node_radius_multiplier=0.0005", &u);
-  if (u)
-    pref.node_radius_multiplier = 0.0005;	/* This is a bug with gnome_config */
-  pref.link_width_multiplier =
-    gnome_config_get_float_with_default
-    ("Diagram/link_width_multiplier=0.0005", &u);
-  if (u)
-    pref.link_width_multiplier = 0.0005;
-  pref.mode = gnome_config_get_int_with_default ("General/mode=-1", &u);	/* DEFAULT */
-  if (pref.mode == IP || pref.mode == TCP)
-    pref.refresh_period =
-      gnome_config_get_int_with_default ("Diagram/refresh_period=3000", &u);
-  else
-    pref.refresh_period =
-      gnome_config_get_int_with_default ("Diagram/refresh_period=800", &u);
-
-  pref.size_mode = gnome_config_get_int_with_default ("Diagram/size_mode=0", &u);	/* LINEAR */
-  pref.node_size_variable = gnome_config_get_int_with_default ("Diagram/node_size_variable=2", &u);	/* INST_OUTBOUND */
-  pref.stack_level =
-    gnome_config_get_int_with_default ("Diagram/stack_level=0", &u);
-  if ((pref.stack_level != 0)
-      && (version_compare (config_file_version, "0.5.4") < 0))
-    g_warning (_("Stack Level is not set to Topmost Recognized Protocol. "
-		 "Please check in the preferences dialog that this is what "
-		 "you really want"));
-  pref.fontname =
-    gnome_config_get_string_with_default
-    ("Diagram/fontname=-*-*-*-*-*-*-*-140-*-*-*-*-iso8859-1", &u);
-  gnome_config_get_vector_with_default
-    ("Diagram/colors=#ff0000;WWW #0000ff;DOMAIN #00ff00 #ffff00 #ff00ff #00ffff #ffffff #ff7700 #ff0077 #ffaa77 #7777ff #aaaa33",
-     &(pref.n_colors), &(pref.colors), &u);
-
-  if (!pref.n_colors || !pref.colors || !strlen(pref.colors[0]))
-  {
-     /* color array defined in prefs, but empty */
-     pref.n_colors = 1;
-     g_free(pref.colors[0]);
-     pref.colors[0] = g_strdup("#7f7f7f");
-  }
-
-  
-  g_free (config_file_version);
-  gnome_config_pop_prefix ();
-}				/* load_config */
-
-static gint
-version_compare (const gchar * a, const gchar * b)
-{
-  guint a_mj, a_mi, a_pl, b_mj, b_mi, b_pl;
-
-  g_assert (a != NULL);
-  g_assert (b != NULL);
-
-  /* TODO What should we return if there was a problem? */
-  g_return_val_if_fail ((get_version_levels (a, &a_mj, &a_mi, &a_pl)
-			 && get_version_levels (b, &b_mj, &b_mi, &b_pl)), 0);
-  if (a_mj < b_mj)
-    return -1;
-  else if (a_mj > b_mj)
-    return 1;
-  else if (a_mi < b_mi)
-    return -1;
-  else if (a_mi > b_mi)
-    return 1;
-  else if (a_pl < b_pl)
-    return -1;
-  else if (a_pl > b_pl)
-    return 1;
-  else
-    return 0;
-}
-
-static gboolean
-get_version_levels (const gchar * version_string,
-		    guint * major, guint * minor, guint * patch)
-{
-  gchar **tokens;
-
-  g_assert (version_string != NULL);
-
-  tokens = g_strsplit (version_string, ".", 0);
-  g_return_val_if_fail ((tokens
-			 && tokens[0] && tokens[1] && tokens[2]
-			 && sscanf (tokens[0], "%d", major)
-			 && sscanf (tokens[1], "%d", minor)
-			 && sscanf (tokens[2], "%d", patch)), FALSE);
-  g_strfreev (tokens);
-  return TRUE;
-}
-
-
-
-/* saves configuration to .gnome/Etherape */
-/* It's not static since it will be called from the GUI */
-void
-save_config (char *prefix)
-{
-  gnome_config_push_prefix (prefix);
-  gnome_config_set_bool ("Diagram/diagram_only", pref.diagram_only);
-  gnome_config_set_bool ("Diagram/group_unk", pref.group_unk);
-  gnome_config_set_bool ("Diagram/nofade", pref.nofade);
-  gnome_config_set_bool ("Diagram/cycle", pref.cycle);
-  gnome_config_set_bool ("Diagram/antialias", pref.antialias);
-  gnome_config_set_float ("Diagram/node_timeout_time",
-			  pref.node_timeout_time);
-  gnome_config_set_float ("Diagram/gui_node_timeout_time",
-			  pref.gui_node_timeout_time);
-  gnome_config_set_float ("Diagram/link_timeout_time",
-			  pref.link_timeout_time);
-  gnome_config_set_float ("Diagram/averaging_time", pref.averaging_time);
-  gnome_config_set_float ("Diagram/node_radius_multiplier",
-			  pref.node_radius_multiplier);
-  gnome_config_set_float ("Diagram/link_width_multiplier",
-			  pref.link_width_multiplier);
-#if 0				/* TODO should we save this? */
-  gnome_config_set_int ("General/mode", pref.mode);
-#endif
-  gnome_config_set_int ("Diagram/refresh_period", pref.refresh_period);
-  gnome_config_set_int ("Diagram/size_mode", pref.size_mode);
-  gnome_config_set_int ("Diagram/node_size_variable",
-			pref.node_size_variable);
-  gnome_config_set_int ("Diagram/stack_level", pref.stack_level);
-  gnome_config_set_string ("Diagram/fontname", pref.fontname);
-
-  gnome_config_set_vector ("Diagram/colors", pref.n_colors,
-			   (const gchar * const *) pref.colors);
-
-  gnome_config_set_string ("General/version", VERSION);
-
-  gnome_config_sync ();
-  gnome_config_pop_prefix ();
-
-  g_my_info (_("Preferences saved"));
-
-}				/* save_config */
 
 
 static void
@@ -425,6 +288,9 @@ set_debug_level (void)
   if (quiet)
     debug_mask = 0;
 
+  /* if someone requested debug infos, enable the relevant flag */
+  pref.is_debug = (debug_mask & G_LOG_LEVEL_DEBUG) ? TRUE : FALSE;
+
   g_log_set_handler (NULL, G_LOG_LEVEL_MASK, (GLogFunc) log_handler, NULL);
   g_my_debug ("debug_mask %d", debug_mask);
 }
