@@ -1,6 +1,6 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
- * $Id: menus.c,v 1.25 2005/08/15 14:24:19 bchiara Exp $
+ * $Id: menus.c,v 1.31 2006/05/13 20:31:05 bchiara Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,16 +22,22 @@
 #include <libgnomeui/gnome-file-entry.h>
 #include <gtk/gtkcontainer.h>
 #include "util.h"
+#include "diagram.h"
+#include "info_windows.h"
+#include "capture.h"
 
 
+static gboolean in_start_capture = FALSE;
+
+static void set_active_interface (void);
+
+
+#if 0
 static GnomeUIInfo help_submenu[] = {
   GNOMEUIINFO_HELP ("etherape"),
   GNOMEUIINFO_END
 };
 
-static gboolean in_start_capture = FALSE;
-
-#if 0
 /* This is here just as an example in case I need it again */
 void
 on_file1_activate (GtkMenuItem * menuitem, gpointer user_data)
@@ -56,24 +62,20 @@ void
 init_menus (void)
 {
   GtkWidget *widget = NULL, *item = NULL;
-  gint err;
-  gchar err_str[300];
   GList *interfaces;
   GSList *group = NULL;
   GString *info_string = NULL;
+  GString *err_str = g_string_new ("");
 
-  /* It seems libglade is not acknowledging the "Use gnome help" option in the 
-   * glade file and so it is not automatically adding the help items in the help
-   * menu. Thus I must add it manually here */
-  interface_list = get_interface_list (&err, err_str);
-
-  interfaces = interface_list;
-
+  interfaces = interface_list_create(err_str);
+  g_my_info (_("get_interface result: '%s'"), err_str->str);
   if (!interfaces)
     {
       g_my_info (_("No suitables interfaces for capture have been found"));
+      g_string_free(err_str, TRUE);
       return;
     }
+  g_string_free(err_str, TRUE);
 
   widget = glade_xml_get_widget (xml, "interfaces_menu");
 
@@ -82,7 +84,7 @@ init_menus (void)
   /* Set up a hidden dummy interface to set when there is no active
    * interface */
   item = gtk_radio_menu_item_new_with_label (group, "apedummy");
-  group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
+  group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
   gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
 
   /* Set up the real interfaces menu entries */
@@ -91,7 +93,7 @@ init_menus (void)
       item =
 	gtk_radio_menu_item_new_with_label (group,
 					    (gchar *) (interfaces->data));
-      group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
+      group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
       gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
       gtk_widget_show (item);
       g_signal_connect_swapped (G_OBJECT (item), "activate",
@@ -103,9 +105,10 @@ init_menus (void)
       interfaces = interfaces->next;
     }
 
-
   g_my_info (info_string->str);
+  g_string_free(info_string, TRUE);
 
+  interface_list_free(interfaces);
 }				/* init_menus */
 
 /* FILE MENU */
@@ -317,6 +320,14 @@ on_stop_menuitem_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 /* View menu */
 
+void
+on_full_screen_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
+{
+  if (menuitem->active)
+    gtk_window_fullscreen((GtkWindow *)app1);
+  else
+    gtk_window_unfullscreen((GtkWindow *)app1);
+} /* on_full_screen_activate */
 
 
 void
@@ -645,9 +656,6 @@ gui_stop_capture (void)
   /* Delete and free protocol information */
   delete_gui_protocols ();
 
-  /* By calling update_diagram, we are forcing node_update
-   * and link_update, thus deleting all nodes and links since
-   * status=STOP. Then the diagram is redrawn */
   widget = glade_xml_get_widget (xml, "canvas1");
   update_diagram (widget);
 
