@@ -1,6 +1,6 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
- * $Id: menus.h,v 1.9 2003/04/06 13:45:42 bchiara Exp $
+ * $Id: menus.h,v 1.11 2006/05/13 20:31:05 bchiara Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,9 +25,6 @@
 #include <libgnomeui/gnome-messagebox.h>
 #include <gtk/gtk.h>
 #include "globals.h"
-#include "util.h"
-
-GList *interface_list = NULL;	/* A list of all usable interface */
 
 void on_open_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_file_cancel_button_clicked (GtkButton * button, gpointer user_data);
@@ -40,6 +37,7 @@ void on_start_menuitem_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_stop_menuitem_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_pause_menuitem_activate (GtkMenuItem * menuitem, gpointer user_data);
 
+void on_full_screen_activate (GtkCheckMenuItem * menuitem, gpointer user_data);
 void on_toolbar_check_activate (GtkCheckMenuItem * menuitem,
 				gpointer user_data);
 void on_legend_check_activate (GtkCheckMenuItem * menuitem,
@@ -48,4 +46,3 @@ void on_status_bar_check_activate (GtkCheckMenuItem * menuitem,
 				   gpointer user_data);
 
 void on_about1_activate (GtkMenuItem * menuitem, gpointer user_data);
-static void set_active_interface (void);
