@@ -7,7 +7,7 @@
  * Gilbert Ramirez <gram@verdict.uthscsa.edu>
  * Much stuff added by Guy Harris <guy@netapp.com>
  *
- * $Id: names_netbios.h,v 1.2 2001/04/19 09:16:08 toledo Exp $
+ * $Id: names_netbios.h,v 1.5 2006/04/29 07:58:35 bchiara Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -33,24 +33,14 @@
 #include <glib.h>
 
 
-#define MAXDNAME        1025	/* maximum domain name length */
-#define NBNAME_BUF_LEN   128
 #define NETBIOS_NAME_LEN  16
 
-#define BYTES_ARE_IN_FRAME(a,b) 1
-/* TODO Find a way to get capture_len here so that I can actually use this macro */
 
 
-int get_dns_name (const gchar * pd, int offset, int dns_data_offset,
-		  char *name, int maxname);
-int process_netbios_name (const gchar * name_ptr, char *name_ret);
 int ethereal_nbns_name (const gchar * pd, int offset,
-			int nbns_data_offset,
-			char *name_ret, int *name_type_ret);
-int get_nbns_name_type_class (const gchar * pd, int offset,
-			      int nbns_data_offset, char *name_ret,
-			      int *name_len_ret, int *name_type_ret,
-			      int *type_ret, int *class_ret);
+                        int pd_len,
+			char *outname, size_t outname_size,
+                        int *name_type_ret);
 
 
 gchar *get_netbios_host_type (int type);
